using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace SpaceRace_del2
{
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        Texture2D level;
        Texture2D ship_normal, ship_acc;
        SpaceShip ship;

        Vector2 gravity = new Vector2(0, 0.01f);
        KeyboardState prev_ks = new KeyboardState();

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        protected override void LoadContent()
        {
            spriteBatch = new SpriteBatch(GraphicsDevice);

            level = Content.Load<Texture2D>("Level01");
            ship_normal = Content.Load<Texture2D>("ship");
            ship_acc = Content.Load<Texture2D>("ship_acc");
            ship = new SpaceShip(ship_normal, ship_acc);
            ship.Position = FindPixel(level, 0xFFFF0000) - new Vector2(0, ship_normal.Height / 2 + 5);
        }

        protected Vector2 FindPixel(Texture2D texture, uint color)
        {
			//Kopiera pixeldata som uint
            uint[] bits = new uint[texture.Width * texture.Height];
            texture.GetData<uint>(bits);

            for (int x = 0; x < level.Width; x++)
            {
                for (int y = 0; y < level.Height; y++)
                {
					//Har vi hittat det vi sker?
                    if (bits[x + y * texture.Width] == color)
                        return new Vector2(x, y);
                }
            }
			//Om inget hittades
            return Vector2.Zero;
        }

        protected override void UnloadContent()
        {
        }

        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //Ls aktuell keyboard status
            KeyboardState ks = Keyboard.GetState();

            //Tryckte vi ned ngra knappar?
            if ((ks.IsKeyDown(Keys.A) && !prev_ks.IsKeyDown(Keys.A))
                || (ks.IsKeyDown(Keys.A) && !ks.IsKeyDown(Keys.D)))
                ship.TurnRate = -0.03f;
            else if ((ks.IsKeyDown(Keys.D) && !prev_ks.IsKeyDown(Keys.D))
                || (ks.IsKeyDown(Keys.D) && !ks.IsKeyDown(Keys.A)))
                ship.TurnRate = 0.03f;
            else if ((!ks.IsKeyDown(Keys.D) && prev_ks.IsKeyDown(Keys.D)) ||
                (!ks.IsKeyDown(Keys.A) && prev_ks.IsKeyDown(Keys.A)))
                ship.TurnRate = 0;

            if (ks.IsKeyDown(Keys.W))
                ship.Speed += gravity + Vector2.Transform(new Vector2(0, -0.03f), Matrix.CreateRotationZ(ship.Rotation));
            else
                ship.Speed += gravity;

            ship.Accelerating = ks.IsKeyDown(Keys.W);
            //Lt skeppet uppdatera sig
            ship.Update(gameTime);
            //Kolla kollision
            ship.CheckCollision(level); 

            //Spara undan keyboard status, som blir fregende status nsta vnda
            prev_ks = ks;

            base.Update(gameTime);
        }

        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();

            //Rita banan
            spriteBatch.Draw(level, Vector2.Zero, Color.White);
            //Rita skeppet
            ship.Draw(gameTime, spriteBatch);

            spriteBatch.End();
            base.Draw(gameTime);
        }

    }
}
